@@ -1,3 +1,4 @@
+__title__ = 'fobi.contrib.apps.djangocms_integration.apps'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
@@ -5,10 +6,9 @@ __all__ = ('Config',)
 
 try:
     from django.apps import AppConfig
-    from fobi.app import app_name
 
     class Config(AppConfig):
-        name = label = app_name(__name__)
+        name = label = 'fobi.contrib.apps.djangocms_integration'
 
 except ImportError:
     pass
